[−][src]Crate heaparray
Re-exports
pub use fat_array_ptr::FatPtrArray as HeapArray; |
pub use fat_array_ptr::*; |
pub use thin_array_ptr::*; |
Modules
| fat_array_ptr | |
| thin_array_ptr |
Traits
| Array | Statically-sized array stored in the heap. |
| Container | Trait for a simple container. |
| CopyDictionary | Key-value map that also uses the |
| CopyMap | Trait for a container indexed by a value that implements copy. The value that indexes the container must implement the Eq trait to. |
| Dictionary | Key-value map that also uses the |
| DynamicArray | Dynamically changing array of values. |
| DynamicContainer | Trait that represents dynamically growing containers. |
| LabelledArray | Array with an optional label struct stored next to the data. |
| Map | Trait for a container indexed by a value. The value that indexes the container must implement the Eq trait to. |