[][src]Module heaparray::alloc

Functions

allocate
deallocate
ensure_align

Ensure size is a multiple of align.

size_align

Get the size and alignment of a type in bytes

size_align_array

Returns the (size, alignment) of an array of elements with capacity T

size_align_multiple

Aligns everything and potentially slightly overestimates the amount of space necessary